@@ -9,6 +9,7 @@
   #   Sys.setenv(RETICULATE_PYTHON = earthengine_python)
 
   # delay load earthengine-api
-  #ee <<- reticulate::import("ee", delay_load = TRUE)
-  ee <<- reticulate::import("ee", delay_load = list(priority = 30))
+  ee <<- reticulate::import("ee", delay_load = TRUE)
+  #ee <<- reticulate::import("ee", delay_load = list(priority = 30))
+
 }
